"use client";
import React from "react";

export type TypeTextProps = { children: string, interval: number | null, onComplete?: () => NodeJS.Timeout | void, reverse?: boolean };
export default function TypeText({ children, interval, onComplete, reverse }: TypeTextProps) {
  const [length, setLength] = React.useState(reverse ? children.length : 0);
  React.useEffect(() => {
    if (interval == null) {
      return;
    }

    if (length > children.length) {
      setLength(children.length);
      return;
    } else if ((!reverse && length == children.length) || (reverse && length == 0)) {
      if (onComplete) {
        const onCompleteRef = onComplete();
        return onCompleteRef && (() => clearInterval(onCompleteRef));
      }
      return;
    }
    
    const intervalRef = setInterval(() => {
      setLength(length + (reverse ? -1 : 1));
    }, interval);

    return () => clearInterval(intervalRef);
  }, [length, children, reverse, interval, onComplete]);

  return <>{children.substring(0, length)}</>
}